aboutsummaryrefslogtreecommitdiffstats
path: root/coin/provisioning/qtci-windows-7-x86
diff options
context:
space:
mode:
authorSimon Hausmann <simon.hausmann@qt.io>2017-01-30 10:33:49 +0100
committerSimon Hausmann <simon.hausmann@qt.io>2017-01-31 12:37:11 +0000
commitdfaa59fcb3c6e00077273f7905fa3de0958f1f56 (patch)
treebd83029d3eb416b4b99e1e00f9c4b1fb35a8b448 /coin/provisioning/qtci-windows-7-x86
parenta20cc5b45263e9a10394fc855d9ac3454512fd52 (diff)
Bump Android API level to 21
This extends commit f3b0b9e292b4c267f6cc1f7a214023d5f9db0b65 to the macOS and Windows platforms. Change-Id: I180d81266897582cee1bec5938fbd3bb9c5c2ee3 Task-number: QTBUG-58367 Reviewed-by: Eskil Abrahamsen Blomfeldt <eskil.abrahamsen-blomfeldt@qt.io>
Diffstat (limited to 'coin/provisioning/qtci-windows-7-x86')
-rw-r--r--coin/provisioning/qtci-windows-7-x86/06-android.ps18
1 files changed, 4 insertions, 4 deletions
diff --git a/coin/provisioning/qtci-windows-7-x86/06-android.ps1 b/coin/provisioning/qtci-windows-7-x86/06-android.ps1
index 96be39a3..ca641d25 100644
--- a/coin/provisioning/qtci-windows-7-x86/06-android.ps1
+++ b/coin/provisioning/qtci-windows-7-x86/06-android.ps1
@@ -1,10 +1,10 @@
. "$PSScriptRoot\..\common\helpers.ps1"
# This script installs Android sdk and ndk
# It also runs update for SDK API level 18, latest SDK tools, latest platform-tools and build-tools version $sdkBuildToolsVersion
# Android 16 is the minimum requirement for Qt 5.7 applications, but we need something more recent than that for building Qt itself.
# E.g the bluetooth features that require Android 18 will disable themselves dynamically when running on Android 16 device.
# That's why we need to use Andoid-18 API version and decision was made to use it also with Qt 5.6.
# NDK
$ndkVersion = "r10e"
@@ -17,7 +17,7 @@ $ndkZip = "c:\Windows\Temp\android_ndk_$ndkVersion.zip"
# SDK
$sdkVersion = "r24.4.1"
$sdkApi = "ANDROID_API_VERSION"
-$sdkApiLevel = "android-18"
+$sdkApiLevel = "android-21"
$sdkBuildToolsVersion = "23.0.3"
$sdkCachedUrl= "http://ci-files01-hki.ci.local/input/android/android-sdk_$sdkVersion-windows.zip"
$sdkOfficialUrl = "https://dl.google.com/android/android-sdk_$sdkVersion-windows.zip"
@@ -1,10 +1,10 @@
. "$PSScriptRoot\..\common\helpers.ps1"
# This script installs Android sdk and ndk
-# It also runs update for SDK API level 18, latest SDK tools, latest platform-tools and build-tools version $sdkBuildToolsVersion
+# It also runs update for SDK API level 21, latest SDK tools, latest platform-tools and build-tools version $sdkBuildToolsVersion
# Android 16 is the minimum requirement for Qt 5.7 applications, but we need something more recent than that for building Qt itself.
@@ -1,10 +1,10 @@
# Android 16 is the minimum requirement for Qt 5.7 applications, but we need something more recent than that for building Qt itself.
-# E.g the bluetooth features that require Android 18 will disable themselves dynamically when running on Android 16 device.
-# That's why we need to use Andoid-18 API version and decision was made to use it also with Qt 5.6.
+# E.g The Bluetooth features that require Android 21 will disable themselves dynamically when running on an Android 16 device.
+# That's why we need to use Andoid-21 API version in Qt 5.9.
# NDK
$ndkVersion = "r10e"